# Server Demo

**Application Scenario:** Web API (powered by FastAPI)

**Telemetry Form:** Verbose Textual Logs

🚧 Work in progress. Please come back later. 🚧


Our basic server demo is a simple web server that serves...
It is written in [FastAPI](https://github.com/tiangolo/fastapi).

Install the dependencies by navigating into the `examples/server_demo` directory and running:

```bash
pip install -r requirements.txt
```

Then, run the server with:

```bash
uvicorn main:app --reload
```